@@ -14,6 +14,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with launchpadlib. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import print_function
+
 """launchpadlib credentials and authentication support."""
 
 __metaclass__ = type
@@ -28,21 +30,44 @@ __all__ = [
     ]
 
 import cgi
-from cStringIO import StringIO
+try:
+    from cStringIO import StringIO
+except ImportError:
+    from io import StringIO
+
 import httplib2
 import os
+from select import select
 import stat
+from sys import stdin
 import time
-from urllib import urlencode
-from urlparse import urljoin
+try:
+    from urllib.parse import urlencode
+except ImportError:
+    from urllib import urlencode
+try:
+    from urllib.parse import urljoin
+except ImportError:
+    from urlparse import urljoin
 import webbrowser
 from base64 import (
     b64decode,
     b64encode,
     )
 
-import simplejson
+try:
+    import json
+except ImportError:
+    import simplejson as json
 
+if bytes is str:
+    # Python 2
+    unicode_type = unicode
+    binary_type = str
+else:
+    unicode_type = str
+    binary_type = bytes
+    
 from lazr.restfulclient.errors import HTTPError
 from lazr.restfulclient.authorize.oauth import (
     AccessToken as _AccessToken,
@@ -61,6 +86,35 @@ access_token_poll_time = 1
 EXPLOSIVE_ERRORS = (MemoryError, KeyboardInterrupt, SystemExit)
 
 
+def _ssl_certificate_validation_disabled():
+    """Whether the user has disabled SSL certificate connection.
+
+    Some testing servers have broken certificates.  Rather than raising an
+    error, we allow an environment variable,
+    ``LP_DISABLE_SSL_CERTIFICATE_VALIDATION`` to disable the check.
+    """
+    # XXX: Copied from lazr/restfulclient/_browser.py.  Once it appears in a
+    # released version of lazr.restfulclient, depend on that new version and
+    # delete this copy.
+    return bool(
+        os.environ.get('LP_DISABLE_SSL_CERTIFICATE_VALIDATION', False))
+
+
+def _http_post(url, headers, params):
+    """POST to ``url`` with ``headers`` and a body of urlencoded ``params``.
+
+    Wraps it up to make sure we avoid the SSL certificate validation if our
+    environment tells us to.  Also, raises an error on non-200 statuses.
+    """
+    cert_disabled = _ssl_certificate_validation_disabled()
+    response, content = httplib2.Http(
+        disable_ssl_certificate_validation=cert_disabled).request(
+        url, method='POST', headers=headers, body=urlencode(params))
+    if response.status != 200:
+        raise HTTPError(response, content)
+    return response, content
+
+
 class Credentials(OAuthAuthorizer):
     """Standard credentials storage and usage class.
 
@@ -84,6 +138,8 @@ class Credentials(OAuthAuthorizer):
         sio = StringIO()
         self.save(sio)
         serialized = sio.getvalue()
+        if isinstance(serialized, unicode_type):
+            serialized = serialized.encode('utf-8')
         return serialized
 
     @classmethod
@@ -93,6 +149,8 @@ class Credentials(OAuthAuthorizer):
         This should probably be moved into OAuthAuthorizer.
         """
         credentials = cls()
+        if not isinstance(value, unicode_type):
+            value = value.decode('utf-8')
         credentials.load(StringIO(value))
         return credentials
 
@@ -131,12 +189,11 @@ class Credentials(OAuthAuthorizer):
         headers = {'Referer': web_root}
         if token_format == self.DICT_TOKEN_FORMAT:
             headers['Accept'] = 'application/json'
-        response, content = httplib2.Http().request(
-            url, method='POST', headers=headers, body=urlencode(params))
-        if response.status != 200:
-            raise HTTPError(response, content)
+        response, content = _http_post(url, headers, params)
+        if isinstance(content, binary_type):
+            content = content.decode('utf-8')
         if token_format == self.DICT_TOKEN_FORMAT:
-            params = simplejson.loads(content)
+            params = json.loads(content)
             if context is not None:
                 params["lp.context"] = context
             self._request_token = AccessToken.from_params(params)
@@ -172,10 +229,7 @@ class Credentials(OAuthAuthorizer):
             oauth_signature='&%s' % self._request_token.secret)
         url = web_root + access_token_page
         headers = {'Referer': web_root}
-        response, content = httplib2.Http().request(
-            url, method='POST', headers=headers, body=urlencode(params))
-        if response.status != 200:
-            raise HTTPError(response, content)
+        response, content = _http_post(url, headers, params)
         self.access_token = AccessToken.from_string(content)
 
 
@@ -246,7 +300,7 @@ class CredentialStore(object):
             self.do_save(credentials, unique_consumer_id)
         except EXPLOSIVE_ERRORS:
             raise
-        except Exception, e:
+        except Exception as e:
             if self.credential_save_failed is None:
                 raise e
             self.credential_save_failed()
@@ -301,7 +355,7 @@ class KeyringCredentialStore(CredentialStore):
     integrating third-party websites into Launchpad.
     """
 
-    B64MARKER = "<B64>"
+    B64MARKER = b"<B64>"
 
     @staticmethod
     def _ensure_keyring_imported():
@@ -333,7 +387,8 @@ class KeyringCredentialStore(CredentialStore):
         credential_string = keyring.get_password(
             'launchpadlib', unique_key)
         if credential_string is not None:
-            credential_string = credential_string.encode('utf8')
+            if isinstance(credential_string, unicode_type):
+                credential_string = credential_string.encode('utf8')
             if credential_string.startswith(self.B64MARKER):
                 try:
                     credential_string = b64decode(
@@ -530,7 +585,17 @@ class AuthorizeRequestTokenWithBrowser(RequestTokenAuthorizationEngine):
     themselves.
     """
 
-    WAITING_FOR_USER = "The authorization page:\n (%s)\nshould be opening in your browser. Use your browser to authorize\nthis program to access Launchpad on your behalf. \n\nWaiting to hear from Launchpad about your decision..."
+    WAITING_FOR_USER = (
+        "The authorization page:\n"
+        " (%s)\n"
+        "should be opening in your browser. Use your browser to authorize\n"
+        "this program to access Launchpad on your behalf.")
+    TIMEOUT_MESSAGE = "Press Enter to continue or wait (%d) seconds..."
+    TIMEOUT = 5
+    WAITING_FOR_LAUNCHPAD = (
+            "Waiting to hear from Launchpad about your decision...")
+    TERMINAL_BROWSERS = ('www-browser', 'links', 'links2', 'lynx',
+                         'elinks', 'elinks-lite', 'netrik', 'w3m')
 
     def __init__(self, service_root, application_name, consumer_name=None,
                  credential_save_failed=None, allow_access_levels=None):
@@ -560,21 +625,39 @@ class AuthorizeRequestTokenWithBrowser(RequestTokenAuthorizationEngine):
         does not require any user interaction--it's solely
         informative.
         """
-        print message
+        print(message)
 
     def make_end_user_authorize_token(self, credentials, request_token):
         """Have the end-user authorize the token in their browser."""
 
         authorization_url = self.authorization_url(request_token)
-        webbrowser.open(authorization_url)
         self.output(self.WAITING_FOR_USER % authorization_url)
+
+        try:
+            browser = webbrowser.get().basename
+            console_browser = browser in self.TERMINAL_BROWSERS
+        except webbrowser.Error:
+            browser = None
+            console_browser = False
+
+        if console_browser:
+            self.output(self.TIMEOUT_MESSAGE % self.TIMEOUT)
+            # Wait a little time before attempting to launch browser,
+            # give users the chance to press a key to skip it anyway.
+            rlist, _, _ = select([stdin], [], [], self.TIMEOUT)
+            if rlist:
+                stdin.readline()
+
+        self.output(self.WAITING_FOR_LAUNCHPAD)
+        if browser is not None:
+            webbrowser.open(authorization_url)
         while credentials.access_token is None:
             time.sleep(access_token_poll_time)
             try:
                 credentials.exchange_request_token_for_access_token(
                     self.web_root)
                 break
-            except HTTPError, e:
+            except HTTPError as e:
                 if e.response.status == 403:
                     # The user decided not to authorize this
                     # application.
@@ -584,8 +667,8 @@ class AuthorizeRequestTokenWithBrowser(RequestTokenAuthorizationEngine):
                     pass
                 else:
                     # There was an error accessing the server.
-                    print "Unexpected response from Launchpad:"
-                    print e
+                    print("Unexpected response from Launchpad:")
+                    print(e)
 
 
 class TokenAuthorizationException(Exception):
