@@ -22,9 +22,14 @@ __all__ = [
     ]
 
 import os
-import urlparse
+try:
+    from urllib.parse import urlsplit
+except:
+    from urlparse import urlsplit
 import warnings
 
+from httplib2 import proxy_info_from_environment
+
 from lazr.restfulclient.resource import (
     CollectionWithKeyBasedLookup,
     HostedFile,           # Re-import for client convenience
@@ -162,7 +167,7 @@ class Launchpad(ServiceRoot):
 
     def __init__(self, credentials, authorization_engine,
                  credential_store, service_root=uris.STAGING_SERVICE_ROOT,
-                 cache=None, timeout=None, proxy_info=None,
+                 cache=None, timeout=None, proxy_info=proxy_info_from_environment,
                  version=DEFAULT_VERSION):
         """Root access to the Launchpad API.
 
@@ -213,7 +218,7 @@ class Launchpad(ServiceRoot):
     @classmethod
     def login(cls, consumer_name, token_string, access_secret,
               service_root=uris.STAGING_SERVICE_ROOT,
-              cache=None, timeout=None, proxy_info=None,
+              cache=None, timeout=None, proxy_info=proxy_info_from_environment,
               authorization_engine=None, allow_access_levels=None,
               max_failed_attempts=None, credential_store=None,
               credential_save_failed=None, version=DEFAULT_VERSION):
@@ -265,7 +270,7 @@ class Launchpad(ServiceRoot):
     @classmethod
     def get_token_and_login(cls, consumer_name,
                             service_root=uris.STAGING_SERVICE_ROOT,
-                            cache=None, timeout=None, proxy_info=None,
+                            cache=None, timeout=None, proxy_info=proxy_info_from_environment,
                             authorization_engine=None, allow_access_levels=[],
                             max_failed_attempts=None, credential_store=None,
                             credential_save_failed=None,
@@ -361,7 +366,7 @@ class Launchpad(ServiceRoot):
     @classmethod
     def login_anonymously(
         cls, consumer_name, service_root=uris.STAGING_SERVICE_ROOT,
-        launchpadlib_dir=None, timeout=None, proxy_info=None,
+        launchpadlib_dir=None, timeout=None, proxy_info=proxy_info_from_environment,
         version=DEFAULT_VERSION):
         """Get access to Launchpad without providing any credentials."""
         (service_root, launchpadlib_dir, cache_path,
@@ -375,7 +380,7 @@ class Launchpad(ServiceRoot):
     @classmethod
     def login_with(cls, application_name=None,
                    service_root=uris.STAGING_SERVICE_ROOT,
-                   launchpadlib_dir=None, timeout=None, proxy_info=None,
+                   launchpadlib_dir=None, timeout=None, proxy_info=proxy_info_from_environment,
                    authorization_engine=None, allow_access_levels=None,
                    max_failed_attempts=None, credentials_file=None,
                    version=DEFAULT_VERSION, consumer_name=None,
@@ -596,15 +601,14 @@ class Launchpad(ServiceRoot):
             raise ValueError("Must set $HOME or pass 'launchpadlib_dir' to "
                 "indicate location to store cached data")
         if not os.path.exists(launchpadlib_dir):
-            os.makedirs(launchpadlib_dir, 0700)
-        os.chmod(launchpadlib_dir, 0700)
+            os.makedirs(launchpadlib_dir, 0o700)
+        os.chmod(launchpadlib_dir, 0o700)
         # Determine the real service root.
         service_root = uris.lookup_service_root(service_root)
         # Each service root has its own cache and credential dirs.
-        scheme, host_name, path, query, fragment = urlparse.urlsplit(
-            service_root)
+        scheme, host_name, path, query, fragment = urlsplit(service_root)
         service_root_dir = os.path.join(launchpadlib_dir, host_name)
         cache_path = os.path.join(service_root_dir, 'cache')
         if not os.path.exists(cache_path):
-            os.makedirs(cache_path, 0700)
+            os.makedirs(cache_path, 0o700)
         return (service_root, launchpadlib_dir, cache_path, service_root_dir)
