@@ -1,4 +1,4 @@
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009, 2011 Canonical Ltd.
 
 # This file is part of launchpadlib.
 #
@@ -48,7 +48,6 @@ from launchpadlib.testing.helpers import (
     )
 from launchpadlib.credentials import (
     KeyringCredentialStore,
-    UnencryptedFileCredentialStore,
     )
 
 # A dummy service root for use in tests
@@ -83,7 +82,7 @@ class TestNameLookups(unittest.TestCase):
             self.assertEqual(len(caught), 1)
             warning, = caught
             self.assertTrue(issubclass(warning.category, DeprecationWarning))
-            self.assertTrue("no longer exists" in warning.message.message)
+            self.assertIn("no longer exists", str(warning))
 
     def test_short_names(self):
         # Ensure the short service names are all supported.
@@ -97,7 +96,7 @@ class TestNameLookups(unittest.TestCase):
             self.assertEqual(uris.lookup_service_root('edge'),
                              uris.lookup_service_root('production'))
 
-    def test_edge_service_root_is_production(self):
+    def test_edge_web_root_is_production(self):
         # The edge server no longer exists, so if the client wants
         # edge we give them production.
         with self.edge_deprecation_error():
@@ -181,7 +180,7 @@ class TestServiceNameWithEmbeddedVersion(unittest.TestCase):
         root = uris.service_roots['staging'] + version
         try:
             Launchpad(None, None, None, service_root=root, version=version)
-        except ValueError, e:
+        except ValueError as e:
             self.assertTrue(str(e).startswith(
                 "It looks like you're using a service root that incorporates "
                 'the name of the web service version ("version-foo")'))
@@ -240,7 +239,7 @@ class TestLaunchpadLoginWithCredentialsFile(unittest.TestCase):
         # The credentials are stored unencrypted in the file you
         # specify.
         credentials = Credentials.load_from_path(filename)
-        self.assertEquals(credentials.consumer.key,
+        self.assertEqual(credentials.consumer.key,
                           launchpad.credentials.consumer.key)
         os.remove(filename)
 
@@ -306,7 +305,7 @@ class TestLaunchpadLoginWith(KeyringTest):
         launchpadlib_dir = os.path.join(self.temp_dir, 'launchpadlib')
         # Verify a newly created-by-hand directory is insecure
         os.mkdir(launchpadlib_dir)
-        os.chmod(launchpadlib_dir, 0755)
+        os.chmod(launchpadlib_dir, 0o755)
         self.assertTrue(os.path.isdir(launchpadlib_dir))
         statinfo = os.stat(launchpadlib_dir)
         mode = stat.S_IMODE(statinfo.st_mode)
@@ -338,7 +337,7 @@ class TestLaunchpadLoginWith(KeyringTest):
         launchpad = NoNetworkLaunchpad.login_with(
             'not important', service_root=SERVICE_ROOT,
             launchpadlib_dir=launchpadlib_dir, version="foo")
-        self.assertEquals(launchpad.passed_in_args['version'], 'foo')
+        self.assertEqual(launchpad.passed_in_args['version'], 'foo')
 
         # Now execute the same test a second time. This time, the
         # credentials are loaded from disk and a different code path
@@ -347,7 +346,7 @@ class TestLaunchpadLoginWith(KeyringTest):
         launchpad = NoNetworkLaunchpad.login_with(
             'not important', service_root=SERVICE_ROOT,
             launchpadlib_dir=launchpadlib_dir, version="bar")
-        self.assertEquals(launchpad.passed_in_args['version'], 'bar')
+        self.assertEqual(launchpad.passed_in_args['version'], 'bar')
 
     def test_application_name_is_propagated(self):
         # Create a Launchpad instance for a given application name.
@@ -358,7 +357,7 @@ class TestLaunchpadLoginWith(KeyringTest):
         launchpad = NoNetworkLaunchpad.login_with(
             'very important', service_root=SERVICE_ROOT,
             launchpadlib_dir=launchpadlib_dir)
-        self.assertEquals(
+        self.assertEqual(
             launchpad.credentials.consumer.application_name, 'very important')
 
         # Now execute the same test a second time. This time, the
@@ -369,7 +368,7 @@ class TestLaunchpadLoginWith(KeyringTest):
         launchpad = NoNetworkLaunchpad.login_with(
             'very important', service_root=SERVICE_ROOT,
             launchpadlib_dir=launchpadlib_dir)
-        self.assertEquals(
+        self.assertEqual(
             launchpad.credentials.consumer.application_name, 'very important')
 
     def test_authorization_engine_is_propagated(self):
@@ -379,8 +378,8 @@ class TestLaunchpadLoginWith(KeyringTest):
         engine = NoNetworkAuthorizationEngine(
             SERVICE_ROOT, 'application name')
         NoNetworkLaunchpad.login_with(authorization_engine=engine)
-        self.assertEquals(engine.request_tokens_obtained, 1)
-        self.assertEquals(engine.access_tokens_obtained, 1)
+        self.assertEqual(engine.request_tokens_obtained, 1)
+        self.assertEqual(engine.access_tokens_obtained, 1)
 
     def test_login_with_must_identify_application(self):
         # If you call login_with without identifying your application
@@ -444,10 +443,10 @@ class TestLaunchpadLoginWith(KeyringTest):
         # levels into login_with().
         launchpad = NoNetworkLaunchpad.login_with(
             consumer_name="consumer", allow_access_levels=['FOO'])
-        self.assertEquals(launchpad.credentials.consumer.key, "consumer")
-        self.assertEquals(launchpad.credentials.consumer.application_name,
+        self.assertEqual(launchpad.credentials.consumer.key, "consumer")
+        self.assertEqual(launchpad.credentials.consumer.application_name,
                           None)
-        self.assertEquals(launchpad.authorization_engine.allow_access_levels,
+        self.assertEqual(launchpad.authorization_engine.allow_access_levels,
                           ['FOO'])
 
     def test_desktop_integration_doesnt_happen_without_consumer_name(self):
@@ -457,7 +456,7 @@ class TestLaunchpadLoginWith(KeyringTest):
         # integration is performed.
         launchpad = NoNetworkLaunchpad.login_with(
             'application name', allow_access_levels=['FOO'])
-        self.assertEquals(launchpad.authorization_engine.allow_access_levels,
+        self.assertEqual(launchpad.authorization_engine.allow_access_levels,
                           ['DESKTOP_INTEGRATION'])
 
     def test_no_credentials_creates_new_credential(self):
@@ -472,7 +471,7 @@ class TestLaunchpadLoginWith(KeyringTest):
                          NoNetworkAuthorizationEngine.ACCESS_TOKEN_KEY)
         self.assertEqual(launchpad.credentials.consumer.application_name,
                          'app name')
-        self.assertEquals(launchpad.authorization_engine.allow_access_levels,
+        self.assertEqual(launchpad.authorization_engine.allow_access_levels,
                           ['DESKTOP_INTEGRATION'])
         # The expected arguments were passed in to the Launchpad
         # constructor.
@@ -580,18 +579,17 @@ class TestDeprecatedLoginMethods(KeyringTest):
         # login() works but triggers a deprecation warning.
         with warnings.catch_warnings(record=True) as caught:
             warnings.simplefilter("always")
-            launchpad = NoNetworkLaunchpad.login(
-                'consumer', 'token', 'secret')
-            self.assertEquals(len(caught), 1)
-            self.assertEquals(caught[0].category, DeprecationWarning)
+            NoNetworkLaunchpad.login('consumer', 'token', 'secret')
+            self.assertEqual(len(caught), 1)
+            self.assertEqual(caught[0].category, DeprecationWarning)
 
     def test_get_token_and_login_is_deprecated(self):
         # get_token_and_login() works but triggers a deprecation warning.
         with warnings.catch_warnings(record=True) as caught:
             warnings.simplefilter("always")
-            launchpad = NoNetworkLaunchpad.get_token_and_login('consumer')
-            self.assertEquals(len(caught), 1)
-            self.assertEquals(caught[0].category, DeprecationWarning)
+            NoNetworkLaunchpad.get_token_and_login('consumer')
+            self.assertEqual(len(caught), 1)
+            self.assertEqual(caught[0].category, DeprecationWarning)
 
 
 class TestCredenitialSaveFailedCallback(unittest.TestCase):
@@ -626,7 +624,7 @@ class TestCredenitialSaveFailedCallback(unittest.TestCase):
                 'not important', service_root=service_root,
                 launchpadlib_dir=launchpadlib_dir,
                 credential_save_failed=callback)
-            self.assertEquals(len(callback_called), 1)
+            self.assertEqual(len(callback_called), 1)
 
     def test_default_credentials_save_failed_is_to_raise_exception(self):
         # If saving the credentials did not succeed and no callback was
@@ -668,18 +666,18 @@ class TestMultipleSites(unittest.TestCase):
                 launchpadlib_dir=launchpadlib_dir)
             consumer_name = launchpad.credentials.consumer.key
 
-        application_key = keyring.data.keys()[0][1]
+        application_key = list(keyring.data.keys())[0][1]
 
         # Both the consumer name (normally the name of the application) and
         # the service root (the URL of the service being accessed) are
         # included in the key when storing credentials.
-        self.assert_(service_root in application_key)
-        self.assert_(consumer_name in application_key)
+        self.assertIn(service_root, application_key)
+        self.assertIn(consumer_name, application_key)
 
         # The key used to store the credentials is of this structure (and
         # shouldn't change between releases or stored credentials will be
         # "forgotten").
-        self.assertEquals(application_key, consumer_name + '@' + service_root)
+        self.assertEqual(application_key, consumer_name + '@' + service_root)
 
     def test_same_app_different_servers(self):
         launchpadlib_dir = os.path.join(self.temp_dir, 'launchpadlib')
@@ -700,8 +698,8 @@ class TestMultipleSites(unittest.TestCase):
         # is of the test mechanism, not a test assertion).
         assert len(keyring.data.keys()) == 2
 
-        application_key_1 = keyring.data.keys()[0][1]
-        application_key_2 = keyring.data.keys()[1][1]
+        application_key_1 = list(keyring.data.keys())[0][1]
+        application_key_2 = list(keyring.data.keys())[1][1]
         self.assertNotEqual(application_key_1, application_key_2)
 
 
